HTable (:class:`kanon.tables.htable.HTable`)
============================================

.. currentmodule:: kanon.tables.htable

.. autoclass:: HTable
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~HTable.colnames
      ~HTable.dtype
      ~HTable.groups
      ~HTable.has_masked_columns
      ~HTable.has_masked_values
      ~HTable.has_mixin_columns
      ~HTable.iloc
      ~HTable.indices
      ~HTable.info
      ~HTable.interpolate
      ~HTable.loc
      ~HTable.loc_indices
      ~HTable.mask
      ~HTable.masked
      ~HTable.meta
      ~HTable.opposite
      ~HTable.read
      ~HTable.symmetry
      ~HTable.write

   .. rubric:: Methods Summary

   .. autosummary::

      ~HTable.add_column
      ~HTable.add_columns
      ~HTable.add_index
      ~HTable.add_row
      ~HTable.argsort
      ~HTable.as_array
      ~HTable.convert_bytestring_to_unicode
      ~HTable.convert_unicode_to_bytestring
      ~HTable.copy
      ~HTable.field
      ~HTable.filled
      ~HTable.from_pandas
      ~HTable.get
      ~HTable.group_by
      ~HTable.index_column
      ~HTable.index_mode
      ~HTable.insert_row
      ~HTable.items
      ~HTable.itercols
      ~HTable.iterrows
      ~HTable.keep_columns
      ~HTable.keys
      ~HTable.more
      ~HTable.pformat
      ~HTable.pformat_all
      ~HTable.pprint
      ~HTable.pprint_all
      ~HTable.remove_column
      ~HTable.remove_columns
      ~HTable.remove_indices
      ~HTable.remove_row
      ~HTable.remove_rows
      ~HTable.rename_column
      ~HTable.rename_columns
      ~HTable.replace_column
      ~HTable.reverse
      ~HTable.round
      ~HTable.show_in_browser
      ~HTable.show_in_notebook
      ~HTable.sort
      ~HTable.to_pandas
      ~HTable.values
      ~HTable.values_equal

   .. rubric:: Attributes Documentation

   .. autoattribute:: colnames
   .. autoattribute:: dtype
   .. autoattribute:: groups
   .. autoattribute:: has_masked_columns
   .. autoattribute:: has_masked_values
   .. autoattribute:: has_mixin_columns
   .. autoattribute:: iloc
   .. autoattribute:: indices
   .. autoattribute:: info
   .. autoattribute:: interpolate
   .. autoattribute:: loc
   .. autoattribute:: loc_indices
   .. autoattribute:: mask
   .. autoattribute:: masked
   .. autoattribute:: meta
   .. autoattribute:: opposite
   .. autoattribute:: read
   .. autoattribute:: symmetry
   .. autoattribute:: write

   .. rubric:: Methods Documentation

   .. automethod:: add_column
   .. automethod:: add_columns
   .. automethod:: add_index
   .. automethod:: add_row
   .. automethod:: argsort
   .. automethod:: as_array
   .. automethod:: convert_bytestring_to_unicode
   .. automethod:: convert_unicode_to_bytestring
   .. automethod:: copy
   .. automethod:: field
   .. automethod:: filled
   .. automethod:: from_pandas
   .. automethod:: get
   .. automethod:: group_by
   .. automethod:: index_column
   .. automethod:: index_mode
   .. automethod:: insert_row
   .. automethod:: items
   .. automethod:: itercols
   .. automethod:: iterrows
   .. automethod:: keep_columns
   .. automethod:: keys
   .. automethod:: more
   .. automethod:: pformat
   .. automethod:: pformat_all
   .. automethod:: pprint
   .. automethod:: pprint_all
   .. automethod:: remove_column
   .. automethod:: remove_columns
   .. automethod:: remove_indices
   .. automethod:: remove_row
   .. automethod:: remove_rows
   .. automethod:: rename_column
   .. automethod:: rename_columns
   .. automethod:: replace_column
   .. automethod:: reverse
   .. automethod:: round
   .. automethod:: show_in_browser
   .. automethod:: show_in_notebook
   .. automethod:: sort
   .. automethod:: to_pandas
   .. automethod:: values
   .. automethod:: values_equal
